@@ -14,9 +14,9 @@ def del_selection(_id):
 
 try:
     from google import colab
-except ModuleNotFoundError:
+except (ModuleNotFoundError, ImportError):
     pass
 else:
     colab.output.register_callback('m2g.reset_selection', reset_selection)
     colab.output.register_callback('m2g.set_selection', set_selection)
-    colab.output.register_callback('m2g.del_selection', del_selection)
\ No newline at end of file
+    colab.output.register_callback('m2g.del_selection', del_selection)
